==> qore-1.14.0.tar.bz2: qore-1.14.0/docs/modules/DataProvider/html/search/variables_14.js <==
var searchData=
[
  ['valid_0',['valid',['../class_data_provider_1_1_abstract_data_provider_bulk_record_interface.html#a0cf98a2ae6f1347e69b58b9fcae85d63',1,'DataProvider::AbstractDataProviderBulkRecordInterface::valid()'],['../class_data_provider_1_1_data_provider_bulk_record_iterator.html#a3eec7a19ec1f051b0aaa42cd860e408c',1,'DataProvider::DataProviderBulkRecordIterator::valid()']]],
  ['value_1',['value',['../struct_data_provider_1_1_allowed_value_info.html#a30de38bec82f758f7268aadf192fe979',1,'DataProvider::AllowedValueInfo']]],
  ['varargs_2',['varargs',['../struct_data_provider_1_1_data_provider_expression_info.html#a7ac566436632db652b517edb1482ea92',1,'DataProvider::DataProviderExpressionInfo']]],
  ['varchar_3',['VARCHAR',['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'Qore::SQL::VARCHAR()'],['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'VARCHAR()(Global Namespace)']]],
  ['vdiscard_4',['VDISCARD',['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore::VDISCARD()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'VDISCARD()(Global Namespace)']]],
  ['vdsusp_5',['VDSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore::VDSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'VDSUSP()(Global Namespace)']]],
  ['veof_6',['VEOF',['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore::VEOF()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'VEOF()(Global Namespace)']]],
  ['veol_7',['VEOL',['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore::VEOL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'VEOL()(Global Namespace)']]],
  ['veol2_8',['VEOL2',['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore::VEOL2()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'VEOL2()(Global Namespace)']]],
  ['verase_9',['VERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore::VERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'VERASE()(Global Namespace)']]],
  ['versionmajor_10',['VersionMajor',['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore::VersionMajor()'],['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'VersionMajor()(Global Namespace)']]],
  ['versionminor_11',['VersionMinor',['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore::VersionMinor()'],['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'VersionMinor()(Global Namespace)']]],
  ['versionstring_12',['VersionString',['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore::VersionString()'],['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'VersionString()(Global Namespace)']]],
  ['versionsub_13',['VersionSub',['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore::VersionSub()'],['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'VersionSub()(Global Namespace)']]],
  ['vintr_14',['VINTR',['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore::VINTR()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'VINTR()(Global Namespace)']]],
  ['vkill_15',['VKILL',['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore::VKILL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'VKILL()(Global Namespace)']]],
  ['vlnext_16',['VLNEXT',['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore::VLNEXT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'VLNEXT()(Global Namespace)']]],
  ['vmin_17',['VMIN',['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore::VMIN()'],['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'VMIN()(Global Namespace)']]],
  ['vquit_18',['VQUIT',['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore::VQUIT()'],['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'VQUIT()(Global Namespace)']]],
  ['vreprint_19',['VREPRINT',['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore::VREPRINT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'VREPRINT()(Global Namespace)']]],
  ['vstart_20',['VSTART',['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore::VSTART()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'VSTART()(Global Namespace)']]],
  ['vstatus_21',['VSTATUS',['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore::VSTATUS()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'VSTATUS()(Global Namespace)']]],
  ['vstop_22',['VSTOP',['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore::VSTOP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'VSTOP()(Global Namespace)']]],
  ['vsusp_23',['VSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore::VSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'VSUSP()(Global Namespace)']]],
  ['vtime_24',['VTIME',['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore::VTIME()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'VTIME()(Global Namespace)']]],
  ['vwerase_25',['VWERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore::VWERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'VWERASE()(Global Namespace)']]]
];

==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/DataProvider/html/search/variables_14.js <==
var searchData=
[
  ['valid_0',['valid',['../class_data_provider_1_1_data_provider_bulk_record_iterator.html#a3eec7a19ec1f051b0aaa42cd860e408c',1,'DataProvider::DataProviderBulkRecordIterator::valid()'],['../class_data_provider_1_1_abstract_data_provider_bulk_record_interface.html#a0cf98a2ae6f1347e69b58b9fcae85d63',1,'DataProvider::AbstractDataProviderBulkRecordInterface::valid()']]],
  ['value_1',['value',['../struct_data_provider_1_1_allowed_value_info.html#a30de38bec82f758f7268aadf192fe979',1,'DataProvider::AllowedValueInfo']]],
  ['varargs_2',['varargs',['../struct_data_provider_1_1_data_provider_expression_info.html#a7ac566436632db652b517edb1482ea92',1,'DataProvider::DataProviderExpressionInfo']]],
  ['varchar_3',['VARCHAR',['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'Qore::SQL::VARCHAR()'],['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'VARCHAR()(Global Namespace)']]],
  ['vdiscard_4',['VDISCARD',['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore::VDISCARD()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'VDISCARD()(Global Namespace)']]],
  ['vdsusp_5',['VDSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore::VDSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'VDSUSP()(Global Namespace)']]],
  ['veof_6',['VEOF',['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore::VEOF()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'VEOF()(Global Namespace)']]],
  ['veol_7',['VEOL',['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'VEOL()(Global Namespace)'],['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore::VEOL()']]],
  ['veol2_8',['VEOL2',['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore::VEOL2()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'VEOL2()(Global Namespace)']]],
  ['verase_9',['VERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore::VERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'VERASE()(Global Namespace)']]],
  ['versionmajor_10',['VersionMajor',['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore::VersionMajor()'],['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'VersionMajor()(Global Namespace)']]],
  ['versionminor_11',['VersionMinor',['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore::VersionMinor()'],['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'VersionMinor()(Global Namespace)']]],
  ['versionstring_12',['VersionString',['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore::VersionString()'],['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'VersionString()(Global Namespace)']]],
  ['versionsub_13',['VersionSub',['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'VersionSub()(Global Namespace)'],['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore::VersionSub()']]],
  ['vintr_14',['VINTR',['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore::VINTR()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'VINTR()(Global Namespace)']]],
  ['vkill_15',['VKILL',['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore::VKILL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'VKILL()(Global Namespace)']]],
  ['vlnext_16',['VLNEXT',['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore::VLNEXT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'VLNEXT()(Global Namespace)']]],
  ['vmin_17',['VMIN',['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore::VMIN()'],['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'VMIN()(Global Namespace)']]],
  ['vquit_18',['VQUIT',['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore::VQUIT()'],['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'VQUIT()(Global Namespace)']]],
  ['vreprint_19',['VREPRINT',['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'VREPRINT()(Global Namespace)'],['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore::VREPRINT()']]],
  ['vstart_20',['VSTART',['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore::VSTART()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'VSTART()(Global Namespace)']]],
  ['vstatus_21',['VSTATUS',['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore::VSTATUS()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'VSTATUS()(Global Namespace)']]],
  ['vstop_22',['VSTOP',['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore::VSTOP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'VSTOP()(Global Namespace)']]],
  ['vsusp_23',['VSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore::VSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'VSUSP()(Global Namespace)']]],
  ['vtime_24',['VTIME',['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore::VTIME()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'VTIME()(Global Namespace)']]],
  ['vwerase_25',['VWERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore::VWERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'VWERASE()(Global Namespace)']]]
];
